@@ -1,4 +1,5 @@
 package Class::Date::Rel;
+our $AUTHORITY = 'cpan:YANICK';
 use strict;
 use warnings;
 
@@ -141,3 +142,43 @@ sub mon_part { shift->[cs_mon] }
 
 1;
 
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Class::Date::Rel
+
+=head1 VERSION
+
+version 1.1.16
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+dLux (Szabó, Balázs) <dlux@dlux.hu>
+
+=item *
+
+Gabor Szabo <szabgab@gmail.com>
+
+=item *
+
+Yanick Champoux <yanick@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018, 2014, 2010, 2003 by Balázs Szabó.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
